referrerpolicy=no-referrer-when-downgrade

ancestor_relay_parent_info

Function ancestor_relay_parent_info 

pub fn ancestor_relay_parent_info<T: Config>(
    session_index: SessionIndex,
    relay_parent: T::Hash,
) -> Option<RelayParentInfo<T::Hash, BlockNumberFor<T>>>
Implementation of ancestor_relay_parent_info runtime API.

Looks up relay parent info for an ancestor block. A block is not in its own AllowedRelayParents (it gets added during the next block’s inherent), so querying a block about itself always returns None.